@@ -14,8 +14,9 @@ for (j in 1:nep) { for (z in 1:ncomp) {
 defrmat[z,j]=( (sum((Cmat[z,])^2*varmat[,j]/ssvec))^2 ) / 
              sum( ( (Cmat[z,])^4*varmat[,j]^2 ) / ( ssvec^2*(ssvec-1) ) ) }}
 defrmat[defrmat<2] <- 2                                                  # to be well-defined
+defrvec <- apply(X=defrmat, MARGIN=1, FUN=min)                           # minimum over the rows/endpoints
 
-CovMatDat <- CorrMatDat <- list()                                        # list of covariance/ correlation matrices of the data
+CovMatDat <- CorrMatDat <- list()                                        # list of covariance/correlation matrices of the data
 for (i in 1:ntr) { CovMatDat[[i]]  <- cov(trlist[[i]])
                    CorrMatDat[[i]] <- cov2cor(CovMatDat[[i]]) }
 
@@ -34,26 +35,26 @@ for (z in 1:ncomp) {
   }
   R <- rbind(R, Rrow)                                                    # correlation matrix for test.stat
 }
-diag(R)=rep(1,times=nrow(R))
+diag(R) <- 1
 
 test.stat <- p.val.adj <- p.val.raw <- matrix(nrow=ncomp, ncol=nep)      # matrices of test statistics and p.vals
 for (z in 1:ncomp) { for (i in 1:nep) {
   test.stat[z,i]=( (t(Cmat[z,])%*%meanmat[,i]) - Margin[z,i] ) /
                  sqrt( t(Cmat[z,])%*%diag(varmat[,i])%*%M%*%(Cmat[z,]) )
   if (alternative=="greater") {
-    p.val.adj[z,i]=1-pmvt(lower=-Inf,upper=rep(test.stat[z,i],times=ncomp*nep),df=defrmat[z,i],corr=R)[1]
-    p.val.raw[z,i]=pt(q=test.stat[z,i],df=defrmat[z,i],lower.tail=FALSE) }
+    p.val.adj[z,i]=1-pmvt(lower=-Inf,upper=rep(test.stat[z,i],times=ncomp*nep),df=defrvec[z],corr=R)[1]
+    p.val.raw[z,i]=pt(q=test.stat[z,i],df=defrvec[z],lower.tail=FALSE) }
   if (alternative=="less") {
-    p.val.adj[z,i]=1-pmvt(lower=rep(test.stat[z,i],times=ncomp*nep),upper=Inf,df=defrmat[z,i],corr=R)[1]
-    p.val.raw[z,i]=pt(q=test.stat[z,i],df=defrmat[z,i],lower.tail=TRUE) }
+    p.val.adj[z,i]=1-pmvt(lower=rep(test.stat[z,i],times=ncomp*nep),upper=Inf,df=defrvec[z],corr=R)[1]
+    p.val.raw[z,i]=pt(q=test.stat[z,i],df=defrvec[z],lower.tail=TRUE) }
   if (alternative=="two.sided") {
     p.val.adj[z,i]=1-pmvt(lower=rep(-abs(test.stat[z,i]),times=ncomp*nep),upper=rep(abs(test.stat[z,i]),times=ncomp*nep),
-                   df=defrmat[z,i],corr=R)[1]
-    p.val.raw[z,i]=min(pt(q=abs(test.stat[z,i]),df=defrmat[z,i],lower.tail=FALSE)*2,1) }
+                   df=defrvec[z],corr=R)[1]
+    p.val.raw[z,i]=min(pt(q=abs(test.stat[z,i]),df=defrvec[z],lower.tail=FALSE)*2,1) }
 }}
 
 list(estimate=estimate, statistic=test.stat, p.val.raw=p.val.raw, p.val.adj=p.val.adj,
-     CovMatDat=CovMatDat, CorrMatDat=CorrMatDat, CorrMatComp=R, degr.fr=defrmat,
+     CovMatDat=CovMatDat, CorrMatDat=CorrMatDat, CorrMatComp=R, degr.fr=defrvec,
      Cmat=Cmat, Margin=Margin, alternative=alternative)
 
 }
